@@ -2,6 +2,7 @@
 
 import contextlib
 import time
+import os
 
 @contextlib.contextmanager
 def TimingBlock(name, N=None):
@@ -13,3 +14,10 @@ def TimingBlock(name, N=None):
     else:
         print "[%0.1f][timing] %s: %fs" % (start, name, dt)
 
+@contextlib.contextmanager
+def TestFile(filename, mode='r'):
+    fd = open(filename, mode)
+    yield fd
+    fd.close()
+    os.unlink(filename)
+
